@@ -22,7 +22,15 @@ writable::list get_face_features_c(strings path, integers index) {
 using namespace cpp11;
 
 writable::list get_face_features_c(strings path, integers index) {
+  if (path.size() != index.size()) {
+    cpp11::stop("`path` and `index` must be the same length");
+  }
+
   writable::list features(path.size());
+  if (path.size() == 0) {
+    return features; // Early exit
+  }
+
   std::vector<hb_tag_t> tags;
   unsigned int n_tags = 0;
   char tag_temp[5];
@@ -51,7 +59,7 @@ writable::list get_face_features_c(strings path, integers index) {
     tags.clear();
     tags.reserve(n_tags);
     for (size_t j = 0; j < n_tags; ++j) {
-      hb_tag_t tag;
+      hb_tag_t tag = {};
       tags.push_back(tag);
     }
     if (n_tags > 0) {
@@ -67,7 +75,7 @@ writable::list get_face_features_c(strings path, integers index) {
     tags.clear();
     tags.reserve(n_tags);
     for (size_t j = 0; j < n_tags; ++j) {
-      hb_tag_t tag;
+      hb_tag_t tag = {};
       tags.push_back(tag);
     }
     if (n_tags > 0) {
