@@ -234,10 +234,9 @@ struct ShapeInfo {
 
 template<typename Iterator>
 inline size_t vector_hash(Iterator begin, Iterator end) {
-  typedef typename std::iterator_traits<Iterator>::value_type Type;
   size_t answer = end - begin;
   for (auto iter = begin; iter != end; ++iter) {
-    Type x = *iter;
+    uint32_t x = *iter;
     x = ((x >> 16) ^ x) * 0x45d9f3b;
     x = ((x >> 16) ^ x) * 0x45d9f3b;
     x = (x >> 16) ^ x;
